import { User } from "../../realms/AdminRealm";
import { AuthProvider } from "../AuthProvider";
export interface PasswordAuthProviderConfig {
    autoCreateAdminUser?: boolean;
    saltLength?: number;
    iterations?: number;
    keyLength?: number;
    digest?: string;
    emailHandler?: PasswordEmailHandler;
}
export interface PasswordEmailHandler {
    resetPassword: (email: string, token: string, userAgent: any, remoteIp: string) => Promise<void>;
}
export interface ResetPasswordRequest {
    action: 'reset_password';
}
export interface CompleteResetRequest {
    action: 'complete_reset';
    token: string;
    new_password: string;
}
export declare class PasswordAuthProvider extends AuthProvider {
    name: string;
    private readonly autoCreateAdminUser;
    private readonly saltLength;
    private readonly emailHandler?;
    private iterations;
    private keyLength;
    private digest;
    private passwordRealm;
    constructor(config?: PasswordAuthProviderConfig);
    start(): Promise<void>;
    stop(): Promise<void>;
    authenticateOrCreateUser(body: any): Promise<User>;
    update(user: User, data: any): Promise<{}>;
    updateProviderAccount(providerId: string, user: User, data: ResetPasswordRequest | CompleteResetRequest, isAuthenticated: boolean, userAgent: any, remoteIp: string): Promise<any>;
    deleteUser(userId: string): Promise<boolean>;
    private updatePassword(newPassword, userId);
    private hashPassword(clearTextPassword, salt, iterations, keyLength, digest);
    private createSalt(saltLength);
    private comparePassword(candidatePassword, salt, iterations, keyLength, digest, hash);
    private attemptToRegister(username, password, isAdmin);
    private attemptToLogin(username, password);
}
